@@ -46,7 +46,7 @@ As in :mod:`examples.phase.simple`, we will examine a 1D problem
 >>> mesh = Grid1D(dx=dx, nx=nx)
 
 The Helmholtz free energy functional can be written as the integral
-[BoettingerReview:2002]_ [McFaddenReview:2002]_ [Wheeler:1992]_
+:cite:`BoettingerReview:2002` :cite:`McFaddenReview:2002` :cite:`Wheeler:1992`
 
 .. math::
     
@@ -107,7 +107,7 @@ are the free energy densities of the pure components. There are a
 variety of choices for the interpolation function :math:`p(\phi)` and the
 barrier function :math:`g(\phi)`, 
    
-such as those shown in mod:`examples.phase.simple`
+such as those shown in :mod:`examples.phase.simple`
 
 >>> def p(phi):
 ...     return phi**3 * (6 * phi**2 - 15 * phi + 10)
@@ -374,7 +374,7 @@ or
 
 >>> Dl = Variable(value=1e-5) # cm**2 / s
 >>> Ds = Variable(value=1e-9) # cm**2 / s
->>> D = (Dl - Ds) * phase.arithmeticFaceValue + Dl
+>>> D = (Ds - Dl) * phase.arithmeticFaceValue + Dl
 
 >>> phaseTransformationVelocity = \
 ...  ((enthalpyB - enthalpyA) * p(phase).faceGrad
@@ -508,7 +508,7 @@ Because the phase field interface will not move, and because we've seen in
 earlier examples that the diffusion problem is unconditionally stable, we
 need take only one very large timestep to reach equilibrium
 
->>> dt = 1.e2
+>>> dt = 1.e5
 
 Because the phase field equation is coupled to the composition through
 ``enthalpy`` and ``W`` and the diffusion equation is coupled to the phase
@@ -575,7 +575,35 @@ Because this lower temperature will induce the phase interface to move
 (solidify), we will need to take much smaller timesteps (the time scales of
 diffusion and of phase transformation compete with each other).
 
->>> dt = 1.e-6
+The `CFL limit`_ requires that no interface should advect more than one grid
+spacing in a timestep. We can get a rough idea for the maximum timestep we can
+take by looking at the velocity of convection induced by phase transformation in
+Eq. :eq:`eq:phase:binary:diffusion:canonical`. If we assume that the phase changes from 1 to 0 in a single grid spacing,
+that the diffusivity is `Dl` at the interface, and that the term due to the difference in
+barrier heights is negligible:
+    
+.. math::
+
+   \vec{u}_\phi &= \frac{D_\phi}{C} \nabla \phi
+   \\
+   &\approx
+   \frac{Dl \frac{1}{2} V_m}{R T}
+   \left[
+       \frac{L_B\left(T - T_M^B\right)}{T_M^B} 
+       - \frac{L_A\left(T - T_M^A\right)}{T_M^A}
+   \right] \frac{1}{\Delta x}
+   \\
+   &\approx
+   \frac{Dl \frac{1}{2} V_m}{R T}
+   \left(L_B + L_A\right) \frac{T_M^A - T_M^B}{T_M^A + T_M^B} 
+   \frac{1}{\Delta x}
+   \\
+   &\approx \unit{0.28}{\centi\meter\per\second}
+
+To get a :math:`\text{CFL} = \vec{u}_\phi \Delta t / \Delta x < 1`, we need a
+time step of about :math:`\unit{10^{-5}}{\second}`.
+
+>>> dt = 1.e-5
 
 >>> if __name__ == '__main__':
 ...     timesteps = 100
@@ -618,8 +646,7 @@ expected values.
    examine different temperatures in this example, so we declare :math:`T` 
    as a :class:`~fipy.variables.variable.Variable`
 
-.. .. bibmissing:: /documentation/refs.bib
-    :sort:
+.. _CFL limit: http://en.wikipedia.org/wiki/Courant-Friedrichs-Lewy_condition
 """
 
 __docformat__ = 'restructuredtext'
