@@ -36,7 +36,7 @@ r"""Solve for the impingement of two grains in one dimension.
 
 In this example we solve a coupled phase and orientation equation on a one
 dimensional grid. This is another aspect of the model of Warren, Kobayashi,
-Lobkovsky and Carter [WarrenPolycrystal]_
+Lobkovsky and Carter :cite:`WarrenPolycrystal`
 
 .. index:: Grid1D
 
