@@ -355,8 +355,8 @@ class _PysparseMeshMatrix(_PysparseMatrixFromShape):
 
     @property
     def numpyArray(self):
-        from fipy.tools import parallel
-        if parallel.Nproc == 1:
+        from fipy.tools import parallelComm
+        if parallelComm.Nproc == 1:
             return super(_PysparseMeshMatrix, self).numpyArray
         else:
             return self.asTrilinosMeshMatrix().numpyArray
@@ -417,8 +417,8 @@ class _PysparseIdentityMeshMatrix(_PysparseIdentityMatrix):
         """Create a sparse matrix associated with a `Mesh` with '1' in the diagonal
         
             >>> from fipy import Grid1D
-            >>> from fipy.tools import serial
-            >>> mesh = Grid1D(nx=3, communicator=serial)
+            >>> from fipy.tools import serialComm
+            >>> mesh = Grid1D(nx=3, communicator=serialComm)
             >>> print _PysparseIdentityMeshMatrix(mesh=mesh)
              1.000000      ---        ---    
                 ---     1.000000      ---    
