@@ -43,9 +43,9 @@ def _suite():
     return _LateImportDocTestSuite(docTestModuleNames = (
         'fipy.meshes.mesh',
         'fipy.meshes.mesh2D',
-        'fipy.meshes.grid1D',
-        'fipy.meshes.grid2D',
-        'fipy.meshes.grid3D',
+        'fipy.meshes.nonUniformGrid1D',
+        'fipy.meshes.nonUniformGrid2D',
+        'fipy.meshes.nonUniformGrid3D',
         'fipy.meshes.tri2D',
         'fipy.meshes.gmshMesh',
         'fipy.meshes.periodicGrid1D',
@@ -55,10 +55,11 @@ def _suite():
         'fipy.meshes.uniformGrid3D',
         'fipy.meshes.cylindricalUniformGrid1D',
         'fipy.meshes.cylindricalUniformGrid2D',
-        'fipy.meshes.cylindricalGrid1D',
-        'fipy.meshes.cylindricalGrid2D',
+        'fipy.meshes.cylindricalNonUniformGrid1D',
+        'fipy.meshes.cylindricalNonUniformGrid2D',
         'fipy.meshes.factoryMeshes',
-        'fipy.meshes.abstractMesh'))
+        'fipy.meshes.abstractMesh',
+        'fipy.meshes.representations.gridRepresentation'))
     
 if __name__ == '__main__':
     fipy.tests.testProgram.main(defaultTest='_suite')
