@@ -34,10 +34,7 @@
 
 __docformat__ = 'restructuredtext'
 
-
 from fipy.terms.abstractUpwindConvectionTerm import _AbstractUpwindConvectionTerm
-from fipy.variables.faceVariable import FaceVariable
-from fipy.solvers import DefaultAsymmetricSolver
 
 __all__ = ["UpwindConvectionTerm"]
 
@@ -60,6 +57,7 @@ class UpwindConvectionTerm(_AbstractUpwindConvectionTerm):
         if solver and not solver._canSolveAsymmetric():
             import warnings
             warnings.warn("%s cannot solve assymetric matrices" % solver)
+        from fipy.solvers import DefaultAsymmetricSolver
         return solver or DefaultAsymmetricSolver(*args, **kwargs)
     
     def _testPecletSign(self):
@@ -70,6 +68,7 @@ class UpwindConvectionTerm(_AbstractUpwindConvectionTerm):
             >>> mesh = Grid1D(nx=nx, dx=L / nx)
             >>> var = CellVariable(mesh=mesh)
 
+            >>> from fipy.variables.faceVariable import FaceVariable
             >>> convCoeff = FaceVariable(mesh=mesh, rank=1)
             >>> diffCoeff = FaceVariable(mesh=mesh, value=1e-20)
             >>> x = mesh.faceCenters[0]
