@@ -46,11 +46,12 @@ __all__ = ["VanLeerConvectionTerm"]
 
 class VanLeerConvectionTerm(ExplicitUpwindConvectionTerm):
 
-    def __getGradient(self, normalGradient, gradUpwind):
+    def _getGradient(self, normalGradient, gradUpwind):
         gradUpUpwind = -gradUpwind + 2 * normalGradient
 
         avg = 0.5 * (abs(gradUpwind) + abs(gradUpUpwind))
-        min3 = numerix.minimum(numerix.minimum(abs(gradUpwind), abs(gradUpUpwind)), avg)
+        min3 = numerix.minimum(numerix.minimum(abs(2 * gradUpwind),
+                                               abs(2 * gradUpUpwind)), avg)
 
         grad = numerix.where(gradUpwind * gradUpUpwind < 0.,
                              0., 
@@ -75,16 +76,13 @@ class VanLeerConvectionTerm(ExplicitUpwindConvectionTerm):
         gradUpwind = (oldArray2 - oldArray1) / numerix.take(mesh._cellDistances, interiorIDs)
         
         vol1 = numerix.take(mesh.cellVolumes, id1)
-        self.CFL = interiorCFL / vol1
         
-        oldArray1 += 0.5 * self.__getGradient(numerix.dot(numerix.take(oldArray.grad, id1, axis=-1), interiorFaceNormals), gradUpwind) \
+        oldArray1 += 0.5 * self._getGradient(numerix.dot(numerix.take(oldArray.grad, id1, axis=-1), interiorFaceNormals), gradUpwind) \
             * (vol1 - interiorCFL) / interiorFaceAreas
 
         vol2 = numerix.take(mesh.cellVolumes, id2)
         
-        self.CFL = numerix.maximum(interiorCFL / vol2, self.CFL)
-
-        oldArray2 += 0.5 * self.__getGradient(numerix.dot(numerix.take(oldArray.grad, id2, axis=-1), -interiorFaceNormals), -gradUpwind) \
+        oldArray2 += 0.5 * self._getGradient(numerix.dot(numerix.take(oldArray.grad, id2, axis=-1), -interiorFaceNormals), -gradUpwind) \
             * (vol2 - interiorCFL) / interiorFaceAreas
         
         return oldArray1, oldArray2
