@@ -52,59 +52,60 @@ def _parallelImport():
                 raise Exception("Could not import mpi4py. The package mpi4py is a required package if you are using Trilinos on a Debian platform with Trilinos version 10.0.4 due to a Trilinos bug (see <http://matforge.org/fipy/ticket/420>). Try installing using 'easy_install mpi4py'.")
 
     from fipy.tools.comms.commWrapper import ParallelCommWrapper
-    parallel = ParallelCommWrapper(Epetra=Epetra)
+    parallelComm = ParallelCommWrapper(Epetra=Epetra)
 
-    if parallel.Nproc > 1:
+    if parallelComm.Nproc > 1:
 
         try:
             from mpi4py import MPI
             from fipy.tools.comms.mpi4pyCommWrapper import Mpi4pyCommWrapper
-            parallel = Mpi4pyCommWrapper(Epetra=Epetra, MPI=MPI)
+            parallelComm = Mpi4pyCommWrapper(Epetra=Epetra, MPI=MPI)
         except ImportError:
             raise ImportError("Could not import mpi4py. The package mpi4py is a required package if you are using Trilinos in parallel. Try installing using 'easy_install mpi4py'.")
 
     from fipy.tools.comms.serialCommWrapper import SerialCommWrapper
-    return SerialCommWrapper(Epetra=Epetra), parallel
+    return SerialCommWrapper(Epetra=Epetra), parallelComm
 
 def _getComms():
     from fipy.tools.parser import _parseSolver
     if _parseSolver() in ("trilinos",  "no-pysparse"):
-        serial, parallel = _parallelImport()
+        serialComm, parallelComm = _parallelImport()
     elif _parseSolver() is None:
         try:
-            serial, parallel = _parallelImport()
+            serialComm, parallelComm = _parallelImport()
         except ImportError:
             from fipy.tools.comms.dummyComm import DummyComm
-            serial, parallel = DummyComm(), DummyComm()
+            serialComm, parallelComm = DummyComm(), DummyComm()
     else:
         from fipy.tools.comms.dummyComm import DummyComm
-        serial, parallel = DummyComm(), DummyComm()
+        serialComm, parallelComm = DummyComm(), DummyComm()
         
-    return serial, parallel
+    return serialComm, parallelComm
     
-serial, parallel = _getComms()
+serial, parallel = serialComm, parallelComm = _getComms()
+
 
 from fipy.tests.doctestPlus import register_skipper
 
 register_skipper(flag="SERIAL",
-                 test=lambda: parallel.Nproc == 1,
+                 test=lambda: parallelComm.Nproc == 1,
                  why="more than one processor found",
                  skipWarning=False)
 
 register_skipper(flag="PARALLEL",
-                 test=lambda: parallel.Nproc > 1,
+                 test=lambda: parallelComm.Nproc > 1,
                  why="only one processor found",
                  skipWarning=False)
 
 register_skipper(flag="PROCESSOR_0",
-                 test=lambda: parallel.procID == 0,
+                 test=lambda: parallelComm.procID == 0,
                  why="not running on processor 0",
                  skipWarning=False)
 
 for M in (2, 3):
     for N in range(M):
         register_skipper(flag="PROCESSOR_%d_OF_%d" % (N, M),
-                         test=lambda N=N, M=M: parallel.procID == N and parallel.Nproc == M,
+                         test=lambda N=N, M=M: parallelComm.procID == N and parallelComm.Nproc == M,
                          why="not running on processor %d of %d" % (N, M),
                          skipWarning=False)
 
@@ -115,13 +116,15 @@ from dimensions.physicalField import PhysicalField
 from fipy.tools.numerix import *
 from fipy.tools.vitals import Vitals
 
-__all__ = ["serial",
-           "parallel",
+__all__ = ["serialComm",
+           "parallelComm",
            "dump",
            "numerix",
            "vector",
            "PhysicalField",
-           "Vitals"]
+           "Vitals",
+           "serial",
+           "parallel"]
            
 import os
 if 'FIPY_INCLUDE_NUMERIX_ALL' in os.environ:
