@@ -584,7 +584,11 @@ class PhysicalField(object):
             >>> print a.allclose("1.8288 m")
             1
             >>> a = PhysicalField(((3.,4.),(5.,6.)),"m")
-            >>> a.itemset(PhysicalField("6 ft"))
+            >>> try:
+            ...     a.itemset(PhysicalField("6 ft"))
+            ... except IndexError:
+            ...     # NumPy 1.7 has changed the exception type
+            ...     raise ValueError("can only place a scalar for an  array of size 1")
             Traceback (most recent call last):
                 ...
             ValueError: can only place a scalar for an  array of size 1
