@@ -1,12 +1,16 @@
+__docformat__ = 'restructuredtext'
+
 from fipy.variables.cellToFaceVariable import _CellToFaceVariable
 from fipy.tools.numerix import exp, take, where
 
+__all__ = ["ScharfetterGummelFaceVariable"]
+
 class ScharfetterGummelFaceVariable(_CellToFaceVariable):
     def __init__(self, var, boundaryConditions=()):
         _CellToFaceVariable.__init__(self, var)
         self.bcs = boundaryConditions
         
-    def _calcValuePy(self, alpha, id1, id2):
+    def _calcValue_(self, alpha, id1, id2):
         cell1 = take(self.var,id1)
         cell2 = take(self.var,id2)
         delta = cell1 - cell2
@@ -21,8 +25,6 @@ class ScharfetterGummelFaceVariable(_CellToFaceVariable):
         
         for bc in self.bcs:
             if isinstance(bc, FixedValue):
-                value[bc.faces.getValue()] = bc._getValue()
+                value[bc.faces.value] = bc._value
         
         return value
-        
-    _calcValueIn = _calcValuePy
