@@ -55,11 +55,16 @@ def _suite():
             'fipy.variables.cellVolumeAverageVariable',
             'fipy.variables.modularVariable',
             'fipy.variables.binaryOperatorVariable',
+            'fipy.variables.unaryOperatorVariable',
             'fipy.variables.coupledCellVariable',
             'fipy.variables.cellToFaceVariable',
             'fipy.variables.faceGradVariable',
             'fipy.variables.gaussCellGradVariable',
-            'fipy.variables.faceGradContributionsVariable'
+            'fipy.variables.faceGradContributionsVariable',
+            'fipy.variables.surfactantConvectionVariable',
+            'fipy.variables.surfactantVariable',
+            'fipy.variables.levelSetDiffusionVariable',
+            'fipy.variables.distanceVariable'
         ))
     
 if __name__ == '__main__':
